==> qtjambi-webenginecore-debuginfo-macos-5.15.18.jar: sources/QtJambiWebEngineCore/QWebEngineClientCertificateStore_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtWebEngineCore/qwebengineclientcertificatestore.h>)
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/QVector>
#if __has_include(<QtNetwork/qsslcertificate.h>)
#include <QtNetwork/qsslcertificate.h>
#endif
#if __has_include(<QtNetwork/qsslkey.h>)
#include <QtNetwork/qsslkey.h>
#endif

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(ssl)



#endif // QT_CONFIG(ssl)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineClientCertificateStore::add(QSslCertificate,QSslKey)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_add_1native_1cref_1QSslCertificate_1cref_1QSslKey__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID certificate0,
 QtJambiNativeID privateKey1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::add(QSslCertificate,QSslKey)", __qt_this)
        const QSslCertificate& __qt_certificate0 = QtJambiAPI::valueReferenceFromNativeId<QSslCertificate>(certificate0);
        const QSslKey& __qt_privateKey1 = QtJambiAPI::valueReferenceFromNativeId<QSslKey>(privateKey1);
        __qt_this->add(__qt_certificate0, __qt_privateKey1);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(certificate0)
        Q_UNUSED(privateKey1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateStore::certificates()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_certificates_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        const QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::certificates()const", __qt_this)
        QVector<QSslCertificate> __qt_return_value = __qt_this->certificates();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineClientCertificateStore::clear()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_clear_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::clear()", __qt_this)
        __qt_this->clear();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateStore::remove(QSslCertificate)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_remove_1native_1cref_1QSslCertificate__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID certificate0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::remove(QSslCertificate)", __qt_this)
        const QSslCertificate& __qt_certificate0 = QtJambiAPI::valueReferenceFromNativeId<QSslCertificate>(certificate0);
        __qt_this->remove(__qt_certificate0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(certificate0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineClientCertificateStore(){
    using namespace RegistryAPI;

#if QT_CONFIG(ssl)

    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineClientCertificateStore>("QWebEngineClientCertificateStore", "io/qt/webengine/core/QWebEngineClientCertificateStore");
// BEGIN: function table
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    Q_UNUSED(typeId)

// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(ssl)

}

==> qtjambi-webenginecore-debuginfo-macos-6.5.3.jar: sources/QtJambiWebEngineCore/QWebEngineClientCertificateStore_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#include <QtCore/QVariant>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslkey.h>
#include <QtCore/QList>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(ssl)



#endif // QT_CONFIG(ssl)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineClientCertificateStore::add(QSslCertificate,QSslKey)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_add_1native_1cref_1QSslCertificate_1cref_1QSslKey__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID certificate0,
 QtJambiNativeID privateKey1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::add(QSslCertificate,QSslKey)", __qt_this)
        const QSslCertificate& __qt_certificate0 = QtJambiAPI::objectReferenceFromNativeId<QSslCertificate>(__jni_env, certificate0);
        const QSslKey& __qt_privateKey1 = QtJambiAPI::valueReferenceFromNativeId<QSslKey>(privateKey1);
        __qt_this->add(__qt_certificate0, __qt_privateKey1);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(certificate0)
        Q_UNUSED(privateKey1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateStore::certificates()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_certificates_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        const QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::certificates()const", __qt_this)
        QList<QSslCertificate> __qt_return_value = __qt_this->certificates();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineClientCertificateStore::clear()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_clear_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::clear()", __qt_this)
        __qt_this->clear();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateStore::remove(QSslCertificate)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineClientCertificateStore_remove_1native_1cref_1QSslCertificate__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID certificate0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(ssl)
        QWebEngineClientCertificateStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateStore::remove(QSslCertificate)", __qt_this)
        const QSslCertificate& __qt_certificate0 = QtJambiAPI::objectReferenceFromNativeId<QSslCertificate>(__jni_env, certificate0);
        __qt_this->remove(__qt_certificate0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(certificate0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(ssl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineClientCertificateStore(){
    using namespace RegistryAPI;

#if QT_CONFIG(ssl)

    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineClientCertificateStore>("QWebEngineClientCertificateStore", "io/qt/webengine/core/QWebEngineClientCertificateStore");
// BEGIN: function table
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    Q_UNUSED(typeId)

// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(ssl)

}
